@@ -40,13 +40,14 @@ class AmsetMaker(Maker):
     resubmit: bool = False
     task_document_kwargs: dict = field(default_factory=dict)
 
-    @job(output_schema=AmsetTaskDocument)
+    @job(output_schema=AmsetTaskDocument, data=["transport", "mesh"])
     def make(
         self,
         settings: dict,
         prev_amset_dir: str | Path = None,
         wavefunction_dir: str | Path = None,
         deformation_dir: str | Path = None,
+        bandstructure_dir: str | Path = None,
     ):
         """
         Run an AMSET calculation.
@@ -62,18 +63,34 @@ class AmsetMaker(Maker):
             A directory containing a wavefunction.h5 file.
         deformation_dir : str or Path
             A directory containing a deformation.h5 file.
+        bandstructure_dir : str or Path
+            A directory containing the dense band structure file (vasprun.xml or
+            band_structure_data.json).
         """
         # copy previous inputs
         from_prev = prev_amset_dir is not None
         if prev_amset_dir is not None:
             copy_amset_files(prev_amset_dir)
+        else:
+            if bandstructure_dir is None:
+                raise ValueError(
+                    "Either prev_amset_dir or bandstructure_dir must be set"
+                )
+
+            copy_amset_files(bandstructure_dir)
+
+            if deformation_dir is not None:
+                copy_amset_files(deformation_dir)
+
+            if wavefunction_dir is not None:
+                copy_amset_files(wavefunction_dir)
 
         # write amset settings
         write_amset_settings(settings, from_prev=from_prev)
 
         # run amset
         logger.info("Running AMSET")
-        transport_data = run_amset()[0].transport
+        run_amset()
 
         converged = None
         if self.resubmit:
@@ -82,6 +99,7 @@ class AmsetMaker(Maker):
                 logger.info("No previous transport calculations found.")
                 converged = False
             else:
+                transport_data = loadfn(next(Path().glob("transport_*.json")))
                 converged = check_converged(transport_data, loadfn(prev_transport_file))
 
         if "include_mesh" not in self.task_document_kwargs:
@@ -91,10 +109,17 @@ class AmsetMaker(Maker):
         task_doc = AmsetTaskDocument.from_directory(
             Path.cwd(), **self.task_document_kwargs
         )
-        task_doc.task_label = self.name
         task_doc.converged = converged
 
         # gzip folder
         gzip_dir(".")
 
-        return Response(output=task_doc)
+        # handle resubmission for non-converged calculations
+        replace = None
+        if self.resubmit and not converged:
+            replace = self.make(
+                {"interpolation_factor": settings.get("interpolation_factor", 10) + 5},
+                prev_amset_dir=task_doc.dir_name,
+            )
+
+        return Response(output=task_doc, replace=replace)
