@@ -3,13 +3,10 @@
 from __future__ import annotations
 
 import logging
-import warnings
+import subprocess
 
 import numpy as np
-from amset.core.run import Runner
-from monty.serialization import dumpfn
 from pydash import get
-from ruamel.yaml.error import MantissaNoDotYAML1_1Warning
 
 __all__ = ["run_amset", "check_converged"]
 
@@ -17,29 +14,12 @@ logger = logging.getLogger(__name__)
 _CONVERGENCE_PROPERTIES = ("mobility.overall", "seebeck")
 
 
-def run_amset(**kwargs):
-    """
-    Run amset in the current directory.
-
-    Parameters
-    ----------
-    **kwargs
-        Keyword arguments that will get passed to ``Runner.from_directory``.
-
-    Returns
-    -------
-    AmsetData, dict
-        A tuple of the amset data object and the usage statistics.
-    """
-    warnings.simplefilter("ignore", MantissaNoDotYAML1_1Warning)
-
-    if "directory" not in kwargs:
-        kwargs["directory"] = "."
-    runner = Runner.from_directory(**kwargs)
-
-    amset_data, usage_stats = runner.run(return_usage_stats=True)
-    dumpfn(usage_stats, "timing.json.gz")
-    return amset_data, usage_stats
+def run_amset():
+    """Run amset in the current directory."""
+    # Run AMSET using the command line as calling from python can cause issues
+    # with multiprocessing
+    with open("std_out.log", "w") as f_std, open("std_err.log", "w") as f_err:
+        subprocess.call(["amset", "run"], stdout=f_std, stderr=f_err)
 
 
 def check_converged(
