@@ -6,17 +6,27 @@ import logging
 from dataclasses import dataclass, field
 from pathlib import Path
 
+from custodian.vasp.handlers import (
+    FrozenJobErrorHandler,
+    IncorrectSmearingHandler,
+    LargeSigmaHandler,
+    MeshSymmetryErrorHandler,
+    PositiveEnergyErrorHandler,
+    StdErrHandler,
+    VaspErrorHandler,
+)
 from pymatgen.alchemy.materials import TransformedStructure
 from pymatgen.alchemy.transmuters import StandardTransmuter
 from pymatgen.core.structure import Structure
 
 from atomate2.vasp.jobs.base import BaseVaspMaker, vasp_job
-from atomate2.vasp.sets.base import VaspInputSetGenerator
+from atomate2.vasp.sets.base import VaspInputGenerator
 from atomate2.vasp.sets.core import (
     HSEBSSetGenerator,
     HSERelaxSetGenerator,
     HSEStaticSetGenerator,
     HSETightRelaxSetGenerator,
+    MDSetGenerator,
     NonSCFSetGenerator,
     RelaxSetGenerator,
     StaticSetGenerator,
@@ -36,6 +46,7 @@ __all__ = [
     "TightRelaxMaker",
     "HSETightRelaxMaker",
     "TransmuterMaker",
+    "MDMaker",
 ]
 
 
@@ -48,7 +59,7 @@ class StaticMaker(BaseVaspMaker):
     ----------
     name : str
         The job name.
-    input_set_generator : .VaspInputSetGenerator
+    input_set_generator : .VaspInputGenerator
         A generator used to make the input set.
     write_input_set_kwargs : dict
         Keyword arguments that will get passed to :obj:`.write_vasp_input_set`.
@@ -69,9 +80,7 @@ class StaticMaker(BaseVaspMaker):
     """
 
     name: str = "static"
-    input_set_generator: VaspInputSetGenerator = field(
-        default_factory=StaticSetGenerator
-    )
+    input_set_generator: VaspInputGenerator = field(default_factory=StaticSetGenerator)
 
 
 @dataclass
@@ -83,7 +92,7 @@ class RelaxMaker(BaseVaspMaker):
     ----------
     name : str
         The job name.
-    input_set_generator : .VaspInputSetGenerator
+    input_set_generator : .VaspInputGenerator
         A generator used to make the input set.
     write_input_set_kwargs : dict
         Keyword arguments that will get passed to :obj:`.write_vasp_input_set`.
@@ -104,9 +113,7 @@ class RelaxMaker(BaseVaspMaker):
     """
 
     name: str = "relax"
-    input_set_generator: VaspInputSetGenerator = field(
-        default_factory=RelaxSetGenerator
-    )
+    input_set_generator: VaspInputGenerator = field(default_factory=RelaxSetGenerator)
 
 
 @dataclass
@@ -118,7 +125,7 @@ class TightRelaxMaker(BaseVaspMaker):
     ----------
     name : str
         The job name.
-    input_set_generator : .VaspInputSetGenerator
+    input_set_generator : .VaspInputGenerator
         A generator used to make the input set.
     write_input_set_kwargs : dict
         Keyword arguments that will get passed to :obj:`.write_vasp_input_set`.
@@ -139,7 +146,7 @@ class TightRelaxMaker(BaseVaspMaker):
     """
 
     name: str = "tight relax"
-    input_set_generator: VaspInputSetGenerator = field(
+    input_set_generator: VaspInputGenerator = field(
         default_factory=TightRelaxSetGenerator
     )
 
@@ -153,7 +160,7 @@ class NonSCFMaker(BaseVaspMaker):
     ----------
     name : str
         The job name.
-    input_set_generator : .VaspInputSetGenerator
+    input_set_generator : .VaspInputGenerator
         A generator used to make the input set.
     write_input_set_kwargs : dict
         Keyword arguments that will get passed to :obj:`.write_vasp_input_set`.
@@ -174,9 +181,7 @@ class NonSCFMaker(BaseVaspMaker):
     """
 
     name: str = "non-scf"
-    input_set_generator: VaspInputSetGenerator = field(
-        default_factory=NonSCFSetGenerator
-    )
+    input_set_generator: VaspInputGenerator = field(default_factory=NonSCFSetGenerator)
 
     @vasp_job
     def make(
@@ -224,7 +229,7 @@ class HSERelaxMaker(BaseVaspMaker):
     ----------
     name : str
         The job name.
-    input_set_generator : .VaspInputSetGenerator
+    input_set_generator : .VaspInputGenerator
         A generator used to make the input set.
     write_input_set_kwargs : dict
         Keyword arguments that will get passed to :obj:`.write_vasp_input_set`.
@@ -245,7 +250,7 @@ class HSERelaxMaker(BaseVaspMaker):
     """
 
     name: str = "hse relax"
-    input_set_generator: VaspInputSetGenerator = field(
+    input_set_generator: VaspInputGenerator = field(
         default_factory=HSERelaxSetGenerator
     )
 
@@ -278,7 +283,7 @@ class HSETightRelaxMaker(BaseVaspMaker):
     """
 
     name: str = "hse tight relax"
-    input_set_generator: VaspInputSetGenerator = field(
+    input_set_generator: VaspInputGenerator = field(
         default_factory=HSETightRelaxSetGenerator
     )
 
@@ -292,7 +297,7 @@ class HSEStaticMaker(BaseVaspMaker):
     ----------
     name : str
         The job name.
-    input_set_generator : .VaspInputSetGenerator
+    input_set_generator : .VaspInputGenerator
         A generator used to make the input set.
     write_input_set_kwargs : dict
         Keyword arguments that will get passed to :obj:`.write_vasp_input_set`.
@@ -313,7 +318,7 @@ class HSEStaticMaker(BaseVaspMaker):
     """
 
     name: str = "hse static"
-    input_set_generator: VaspInputSetGenerator = field(
+    input_set_generator: VaspInputGenerator = field(
         default_factory=HSEStaticSetGenerator
     )
 
@@ -334,7 +339,7 @@ class HSEBSMaker(BaseVaspMaker):
     ----------
     name : str
         The job name.
-    input_set_generator : .VaspInputSetGenerator
+    input_set_generator : .VaspInputGenerator
         A generator used to make the input set.
     write_input_set_kwargs : dict
         Keyword arguments that will get passed to :obj:`.write_vasp_input_set`.
@@ -355,9 +360,7 @@ class HSEBSMaker(BaseVaspMaker):
     """
 
     name: str = "hse band structure"
-    input_set_generator: VaspInputSetGenerator = field(
-        default_factory=HSEBSSetGenerator
-    )
+    input_set_generator: VaspInputGenerator = field(default_factory=HSEBSSetGenerator)
 
     @vasp_job
     def make(
@@ -393,7 +396,7 @@ class HSEBSMaker(BaseVaspMaker):
 
         if "parse_dos" not in self.task_document_kwargs:
             # parse DOS only for uniform band structure
-            self.task_document_kwargs["parse_dos"] = mode == "uniform"
+            self.task_document_kwargs["parse_dos"] = "uniform" in mode
 
         if "parse_bandstructure" not in self.task_document_kwargs:
             parse_bandstructure = "uniform" if mode == "gap" else mode
@@ -494,9 +497,7 @@ class TransmuterMaker(BaseVaspMaker):
     name: str = "transmuter"
     transformations: tuple[str, ...] = field(default_factory=tuple)
     transformation_params: tuple[dict, ...] | None = None
-    input_set_generator: VaspInputSetGenerator = field(
-        default_factory=StaticSetGenerator
-    )
+    input_set_generator: VaspInputGenerator = field(default_factory=StaticSetGenerator)
 
     @vasp_job
     def make(
@@ -529,6 +530,62 @@ class TransmuterMaker(BaseVaspMaker):
         return super().make.original(self, structure, prev_vasp_dir)
 
 
+@dataclass
+class MDMaker(BaseVaspMaker):
+    """
+    Maker to create VASP molecular dynamics jobs.
+
+    Parameters
+    ----------
+    name : str
+        The job name.
+    input_set_generator : .VaspInputSetGenerator
+        A generator used to make the input set.
+    write_input_set_kwargs : dict
+        Keyword arguments that will get passed to :obj:`.write_vasp_input_set`.
+    copy_vasp_kwargs : dict
+        Keyword arguments that will get passed to :obj:`.copy_vasp_outputs`.
+    run_vasp_kwargs : dict
+        Keyword arguments that will get passed to :obj:`.run_vasp`.
+    task_document_kwargs : dict
+        Keyword arguments that will get passed to :obj:`.TaskDocument.from_directory`.
+    stop_children_kwargs : dict
+        Keyword arguments that will get passed to :obj:`.should_stop_children`.
+    write_additional_data : dict
+        Additional data to write to the current directory. Given as a dict of
+        {filename: data}. Note that if using FireWorks, dictionary keys cannot contain
+        the "." character which is typically used to denote file extensions. To avoid
+        this, use the ":" character, which will automatically be converted to ".". E.g.
+        ``{"my_file:txt": "contents of the file"}``.
+    """
+
+    name: str = "molecular dynamics"
+
+    input_set_generator: VaspInputGenerator = field(default_factory=MDSetGenerator)
+
+    # Explicitly pass the handlers to not use the default ones. Some default handlers
+    # such as PotimErrorHandler do not apply to MD runs.
+    run_vasp_kwargs: dict = field(
+        default_factory=lambda: {
+            "handlers": (
+                VaspErrorHandler(),
+                MeshSymmetryErrorHandler(),
+                PositiveEnergyErrorHandler(),
+                FrozenJobErrorHandler(),
+                StdErrHandler(),
+                LargeSigmaHandler(),
+                IncorrectSmearingHandler(),
+            )
+        }
+    )
+
+    # Store ionic steps info in a pymatgen Trajectory object instead of in the output
+    # document.
+    task_document_kwargs: dict = field(
+        default_factory=lambda: {"store_trajectory": True}
+    )
+
+
 def _get_transformations(
     transformations: tuple[str, ...], params: tuple[dict, ...] | None
 ):
@@ -543,7 +600,6 @@ def _get_transformations(
         found = False
         for m in (
             "advanced_transformations",
-            "defect_transformations",
             "site_transformations",
             "standard_transformations",
         ):
